@@ -18,6 +18,7 @@ class RequestFailure(SlashCommandError):
     :ivar status: Status code of failed response.
     :ivar msg: Message of failed response.
     """
+
     def __init__(self, status: int, msg: str):
         self.status = status
         self.msg = msg
@@ -34,10 +35,25 @@ class DuplicateCommand(SlashCommandError):
     """
     There is a duplicate command name.
     """
+
     def __init__(self, name: str):
         super().__init__(f"Duplicate command name detected: {name}")
 
 
+class DuplicateCallback(SlashCommandError):
+    """
+    There is a duplicate component callback.
+    """
+
+    def __init__(self, message_id: int, custom_id: str, component_type: int):
+        super().__init__(
+            f"Duplicate component callback detected: "
+            f"message ID {message_id or '<any>'}, "
+            f"custom_id `{custom_id or '<any>'}`, "
+            f"component_type `{component_type or '<any>'}`"
+        )
+
+
 class DuplicateSlashClient(SlashCommandError):
     """
     There are duplicate :class:`.SlashCommand` instances.
@@ -56,11 +72,17 @@ class IncorrectType(SlashCommandError):
     """
 
 
+class IncorrectGuildIDType(SlashCommandError):
+    """
+    Guild ID type passed was incorrect
+    """
+
+
 class IncorrectCommandData(SlashCommandError):
     """
     Incorrect data was passed to a slash command data object
     """
-    
+
 
 class AlreadyResponded(SlashCommandError):
     """
